@@ -272,6 +272,7 @@ def create_menubar(MAIN):
     submenu_import.addAction(actions['import_deltamed'])
     submenu_import.addAction(actions['import_grael'])
     submenu_import.addAction(actions['import_domino'])
+    submenu_import.addAction(actions['import_phillips'])
     submenu_import.addAction(actions['import_prana'])
     submenu_import.addAction(actions['import_remlogic'])
     submenu_import.addAction(actions['import_sandman'])
@@ -282,6 +283,7 @@ def create_menubar(MAIN):
     submenu_import_qual.addAction(actions['import_compumedics_qual'])
     submenu_import_qual.addAction(actions['import_deltamed_qual'])
     submenu_import_qual.addAction(actions['import_domino_qual'])
+    submenu_import_qual.addAction(actions['import_phillips_qual'])
     submenu_import_qual.addAction(actions['import_prana_qual'])
     submenu_import_qual.addAction(actions['import_remlogic_qual'])
     submenu_import_qual.addAction(actions['import_sandman_qual'])
